@@ -42,8 +42,10 @@ def signal_handler(signal, frame):
     raise ExitCommand()
 
 def start():
-    if platform.system() == 'Linux':
+    if platform.system() in ('Linux', 'Darwin'):
         signal.signal(signal.SIGUSR1, signal_handler)
+    else:
+        signal.signal(signal.SIGINT, signal_handler)
     home = expanduser('~')
     path = pathlib.Path(home + '/.c8ylp')
     loglevel = logging.INFO
@@ -139,6 +141,8 @@ def start():
             reconnects = int(option_value)
         elif option_key in ['--help']:
             help()
+    if script_mode:
+        reconnects = -1
     validate_parameter(host, device, extype, config_name,
                        tenant, user, password, token)
     if use_pid:
@@ -147,7 +151,7 @@ def start():
         if use_pid:
             kill_existing_instances()
         else:
-            logging.warn(f'WARNING: Killing existing instances is only support when "--use-pid" is used.')
+            logging.warn(f'WARNING: Killing existing instances is only supported when "--use-pid" is used.')
     client = CumulocityClient(host, tenant, user, password, tfacode, ignore_ssl_validate)
     tenant_id_valid = client.validate_tenant_id()
     if tenant_id_valid is not None:
